@@ -216,7 +216,7 @@ make_bin_package(){
 	rm -rf $BIN_NAME $BIN_NAME.tar.bz2 $BIN_NAME.md5sum
 	
 	cp -a $GS_DIR $BIN_NAME
-	OFED_DIR=$(basename $(ls -d $BIN_NAME/OFED*))
+	OFED_DIR=$(basename $(ls -d $BIN_NAME/$IBED_DIR ))
 	save_os_vars $BIN_NAME/bin-info
 	
 	GS_SRC_RPMS=$(ls $BIN_NAME/SRPMS/*)
@@ -492,7 +492,7 @@ mkdir -p /usr/voltaire/
 rm -rf /usr/voltaire/workarounds/
 cp -a workarounds /usr/voltaire/
 for wa in /usr/voltaire/workarounds/*.wa  ; do 
-		echo running woraround $wa
+		echo running workaround $wa
 		$wa install
 done
 
@@ -541,7 +541,7 @@ if [ -f $script_dir/bin-info ] ; then
 fi
 	
 if [ ! -f $script_dir/install/ofed.conf.$conf ] ; then
-	echo $script_dir/install/ofed.conf.$conf Does no exists using $script_dir/install/ofed.conf.default-noarch
+	echo $script_dir/install/ofed.conf.$conf does not exist. using $script_dir/install/ofed.conf.default-noarch
 	conf=default-noarch
 fi
 
